@@ -45,9 +45,9 @@ sidebarwidget::sidebarwidget(TQWidget* parent, const char* name)
     toolbar->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Minimum);
 
     TDEAction *refresh = new TDEAction( i18n("Refresh"), SmallIcon("view-refresh"),
-        0, TQT_TQOBJECT(this), TQT_SLOT(slotRefresh()), this, "refresh" );
+        0, this, TQ_SLOT(slotRefresh()), this, "refresh" );
     TDEAction *prefs   = new TDEAction( i18n("Settings"), SmallIcon("configure"),
-        0, TQT_TQOBJECT(this), TQT_SLOT(slotConfigure()), this, "preferences" );
+        0, this, TQ_SLOT(slotConfigure()), this, "preferences" );
     refresh->plug(toolbar);
     prefs->plug(toolbar);
 
@@ -90,7 +90,7 @@ void sidebarwidget::slotConfigure()
     if ( settingsDialog == 0 )
     {
       settingsDialog = new KCMultiDialog(0);
-      connect( settingsDialog, TQT_SIGNAL( configCommitted() ), this, TQT_SLOT( slotRefresh() ) );
+      connect( settingsDialog, TQ_SIGNAL( configCommitted() ), this, TQ_SLOT( slotRefresh() ) );
 
       settingsDialog->addModule( "kcmweatherstations.desktop" );
       settingsDialog->addModule( "kcmweatherservice.desktop" );
