@@ -31,7 +31,7 @@ class StationDatabase;
 
 class WeatherService : public TQObject, public DCOPObject
 {
-	Q_OBJECT
+	TQ_OBJECT
 //	
 	K_DCOP
 
@@ -61,15 +61,21 @@ class WeatherService : public TQObject, public DCOPObject
 		TQString windChill(const TQString &stationID);
 		TQString wind(const TQString &stationID);
 		TQString pressure(const TQString &stationID);
-		TQPixmap currentIcon(const TQString &stationID);
-		TQPixmap icon(const TQString &stationID);
-		TQString currentIconString(const TQString &stationID);
-		TQString iconFileName(const TQString &stationID);
+		TQPixmap icon(const TQString &stationID, uint iconSize);
+		TQString iconName(const TQString &stationID, uint iconSize);
+		TQString iconPath(const TQString &stationID, uint iconSize);
 		TQString date(const TQString &stationID);
 		TQString visibility(const TQString &stationID);
 		TQStringList cover(const TQString &stationID);
 		TQStringList weather(const TQString &stationID);
 		bool stationNeedsMaintenance(const TQString &stationID);
+		bool weatherDataAvailable(const TQString &stationID);
+
+		/* compatibility */
+		TQPixmap currentIcon(const TQString &stationID) TDE_DEPRECATED;
+		TQPixmap icon(const TQString &stationID) TDE_DEPRECATED;
+		TQString currentIconString(const TQString &stationID) TDE_DEPRECATED;
+		TQString iconFileName(const TQString &stationID) TDE_DEPRECATED;
 
 		TQString stationName(const TQString &stationID);
 		TQString stationCountry(const TQString &stationID);
